/**
 * Copyright (c) 2002 Bright Side Factory.  All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 *
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 *
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in
 *    the documentation and/or other materials provided with the
 *    distribution.
 *
 * 3. The end-user documentation included with the redistribution,
 *    if any, must include the following acknowledgment:
 *       "This product includes software developed by the
 *        Bright Side Factory (http://www.bs-factory.org/)."
 *    Alternately, this acknowledgment may appear in the software itself,
 *    if and wherever such third-party acknowledgments normally appear.
 *
 * 4. The names "Bright Side", "BS Factory" and "Bright Side Factory" must
 *    not be used to endorse or promote products derived from this
 *    software without prior written permission. For written
 *    permission, please contact info@bs-factory.org.
 *
 * 5. Products derived from this software may not be called "Bright Side",
 *    nor may "Bright Side" appear in their name, without prior written
 *    permission of the Apache Software Foundation.
 *
 * THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
 * OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 * DISCLAIMED.  IN NO EVENT SHALL THE APACHE SOFTWARE FOUNDATION OR
 * ITS CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
 * LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
 * USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
 * ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
 * OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 * SUCH DAMAGE.
 * ====================================================================
 *
 * This software consists of voluntary contributions made by many
 * individuals on behalf of the Bright Side Factory.  For more
 * information on the Bright Side Factory, please see
 * <http://www.bs-factory.org/>.
 */
package com.bsf.lovDemo;

import com.bsf.lovDemo.components.InfoDialog;
import com.bsf.lovDemo.controllers.Actions;
import com.bsf.lovDemo.models.AvailableLovs;
import com.bsf.lovDemo.views.DemoFrame;
import com.jgoodies.plaf.FontSizeHints;
import com.jgoodies.plaf.LookUtils;
import com.jgoodies.plaf.Options;
import com.jgoodies.splash.Splash;
import com.jgoodies.swing.application.AbstractMainFrame;
import com.jgoodies.swing.application.Globals;
import com.jgoodies.swing.application.ResourceManager;
import com.jgoodies.swing.application.Workbench;
import com.jgoodies.swing.convenience.DefaultApplicationStarter;
import com.jgoodies.swing.convenience.ImageSplash;
import com.jgoodies.swing.convenience.SetupManager;
import org.bsf.listOfValues.LOVService;
import org.bsf.listOfValues.client.LovManager;
import org.bsf.remoting.EJBDefinition;
import org.bsf.remoting.http.HttpServiceFactory;

import javax.swing.UIManager;
import javax.swing.plaf.DimensionUIResource;
import java.awt.Color;
import java.awt.Dimension;

/**
 * This is the main class of the LovDemo application. It utilizes the default
 * application startup process from the JGoodies UI framework (you can check
 * this really good framework at http://www.jgoodies.com).
 */
public final class LOVDemo extends DefaultApplicationStarter {
    public static final String LOV_DEMO_VERSION = "1.0.0";

    public static String _host = "www.bs-factory.com";
    public static String _serverContext = "jboss/lovDemo";
    public static int _port = 80;

    /**
     * Configures the splash to set a blue progress bar.
     */
    protected void configureSplash() {
        super.configureSplash();

        // We configure the splash screen
        ImageSplash blueSplash = (ImageSplash) Splash.getProvider();
        blueSplash.setForeground( new Color( 82, 82, 140 ) );
        blueSplash.setBackground( new Color( 189, 193, 205 ) );
    }

    /**
     * Configures the user interface.
     */
    protected void configureUI() {
        Options.setUseSystemFonts( true );
        Options.setGlobalFontSizeHints( FontSizeHints.MIXED2 );
        Options.setDefaultIconSize( new Dimension( 18, 18 ) );
        UIManager.put( "ToolBar.separatorSize", new DimensionUIResource( 6, 18 ) );

        super.configureUI();
    }

    /**
     * Creates and answers the application's main frame.
     */
    protected AbstractMainFrame createMainFrame() {
        return new DemoFrame();
    }

    /**
     * Initializes the controllers used in this demo.
     */
    protected void initializeActions() {
        Actions.registerActions();
    }

    /**
     * Brings up the application.
     * In addition to the superclass behavior, we register help sets.
     */
    protected void launchApplication() {
        super.launchApplication();
    }

    /**
     * Defines a bunch of application wide constants, and launches
     * the boot process for the application.
     */
    public static void main( String[] args ) {
        // The webstart class loader bug
        UIManager.put( "ClassLoader", LookUtils.class.getClassLoader() );

        // Do we have all the parameters ?
        if ( args.length != 3 ) {
            System.out.println( "Missing parameters... [HOST] [SERVER_CONTEXT] [PORT]" );
            System.exit( 1 );
        }

        // We store the given parameters
        _host = args[ 0 ];
        _serverContext = args[ 1 ];
        _port = Integer.parseInt( args[ 2 ] );

        // Boot
        new LOVDemo().boot( new Globals(
                "LOV Demo", // Application name
                "LOVDemo", // prefix for logs and prefs
                LOV_DEMO_VERSION, // version
                "", // full version
                "The Bright Side List Of Values Demo", // description
                "\u00a9 2003", // copyright
                "Bright Side Factory", // vendor
                "com/bsf/lovDemo/", // resource properties URL
                "", // helpset URL
                "", // tip index path
                "http://www.bs-factory.org/", // vendor URL
                "info@bs-factory.com" ) );        // support eMail
    }

    protected void configureSetupManager() {
        // No license so it's accepted by default
        SetupManager.setAcceptedLicense( LOV_DEMO_VERSION );

        // We don't want the application to quit by itself
        System.setProperty( "jgoodies.SystemExitAllowed", "false" );

        try {
            // We initialize the LovManager
            initializeLovManager();

            // Preloading the Lovs
            LovManager.getListOfValues( AvailableLovs.LOV_AUTHORS );
            LovManager.getListOfValues( AvailableLovs.LOV_COUNTRIES );
            LovManager.getListOfValues( AvailableLovs.LOV_AMERICAN_COUNTRIES_WITH_REGION_NAME );
        } catch( Exception e ) {
            // We should display an info dialog explaining the error (one different for each error would be better :o)
            InfoDialog infoDialog = new InfoDialog( Workbench.getMainFrame(), InfoDialog.EXIT_ON_CLOSE );
            infoDialog.openWithMessage( e.getLocalizedMessage(), ResourceManager.getString( "message.will.quit" ) );
        }

        super.configureSetupManager();
    }

    protected void initializeLovManager() {
        // We will go through http
        EJBDefinition lovServiceDefinition = new EJBDefinition( "ejb/LOVService",
                                                                "org.bsf.listOfValues.LOVServiceHome",
                                                                "org.bsf.listOfValues.LOVService" );

        HttpServiceFactory httpServiceFactory = new HttpServiceFactory();

        // We configure the factory...
        httpServiceFactory.setPort( _port );
        httpServiceFactory.setHost( _host );
        httpServiceFactory.setServerContext( _serverContext );

        LovManager.setLovService( (LOVService) httpServiceFactory.getService( lovServiceDefinition ) );
    }
}