/**
 * Copyright (c) 2002 Bright Side Factory.  All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 *
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 *
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in
 *    the documentation and/or other materials provided with the
 *    distribution.
 *
 * 3. The end-user documentation included with the redistribution,
 *    if any, must include the following acknowledgment:
 *       "This product includes software developed by the
 *        Bright Side Factory (http://www.bs-factory.org/)."
 *    Alternately, this acknowledgment may appear in the software itself,
 *    if and wherever such third-party acknowledgments normally appear.
 *
 * 4. The names "Bright Side", "BS Factory" and "Bright Side Factory" must
 *    not be used to endorse or promote products derived from this
 *    software without prior written permission. For written
 *    permission, please contact info@bs-factory.org.
 *
 * 5. Products derived from this software may not be called "Bright Side",
 *    nor may "Bright Side" appear in their name, without prior written
 *    permission of the Apache Software Foundation.
 *
 * THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
 * OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 * DISCLAIMED.  IN NO EVENT SHALL THE APACHE SOFTWARE FOUNDATION OR
 * ITS CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
 * LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
 * USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
 * ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
 * OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 * SUCH DAMAGE.
 * ====================================================================
 *
 * This software consists of voluntary contributions made by many
 * individuals on behalf of the Bright Side Factory.  For more
 * information on the Bright Side Factory, please see
 * <http://www.bs-factory.org/>.
 */
package com.bsf.lovDemo.models;

import com.jgoodies.swing.application.ResourceManager;

import javax.swing.table.AbstractTableModel;
import java.util.List;

/**
 * The TableModel for the table displaying the Persons.
 */
public class PersonTableModel extends AbstractTableModel {
    private static int NB_COLUMNS = 3;

    private static final String[] _columnNames = {
        ResourceManager.getString( "table.column.ref" ),
        ResourceManager.getString( "table.column.name" ),
        ResourceManager.getString( "table.column.country" ),
    };

    private static final String MISSING_DATA = ResourceManager.getString( "table.missing.data" );

    private List _persons = null;

    // *************************************************************************
    // ****************************** Constructor ******************************
    // *************************************************************************

    /**
     * Creates a TableModel whose data is the given List of Person Object. No
     * check is done, it is up to the caller to ensure the Objects validity
     * (just a demo application...).
     *
     * @param p_persons The List of Persons to use, shouldn't be null...
     */
    public PersonTableModel( List p_persons ) {
        super();

        _persons = p_persons;
    }

    // *************************************************************************
    // ************************* TableModel Methods ****************************
    // *************************************************************************

    public String getColumnName( int p_columnIndex ) {
        return _columnNames[ p_columnIndex ];
    }

    public int getRowCount() {
        return _persons.size();
    }

    public int getColumnCount() {
        return NB_COLUMNS;
    }

    public Object getValueAt( int p_rowIndex, int p_columnIndex ) {
        // We retrieve the person corresponding to the given p_rowIndex
        Person aPerson = (Person) _persons.get( p_rowIndex );

        // We locate the valid field corresponding to the given p_columnIndex
        switch( p_columnIndex ) {
            case ( 0 ):
                return aPerson.getRef();
            case ( 1 ):
                return aPerson.getName();
            case ( 2 ):
                return aPerson.getCountryID();
            default:
                // Should never happen... Just in case...
                return MISSING_DATA;
        }
    }
}
