/**
 * Copyright (c) 2002 Bright Side Factory.  All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 *
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 *
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in
 *    the documentation and/or other materials provided with the
 *    distribution.
 *
 * 3. The end-user documentation included with the redistribution,
 *    if any, must include the following acknowledgment:
 *       "This product includes software developed by the
 *        Bright Side Factory (http://www.bs-factory.org/)."
 *    Alternately, this acknowledgment may appear in the software itself,
 *    if and wherever such third-party acknowledgments normally appear.
 *
 * 4. The names "Bright Side", "BS Factory" and "Bright Side Factory" must
 *    not be used to endorse or promote products derived from this
 *    software without prior written permission. For written
 *    permission, please contact info@bs-factory.org.
 *
 * 5. Products derived from this software may not be called "Bright Side",
 *    nor may "Bright Side" appear in their name, without prior written
 *    permission of the Apache Software Foundation.
 *
 * THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
 * OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 * DISCLAIMED.  IN NO EVENT SHALL THE APACHE SOFTWARE FOUNDATION OR
 * ITS CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
 * LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
 * USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
 * ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
 * OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 * SUCH DAMAGE.
 * ====================================================================
 *
 * This software consists of voluntary contributions made by many
 * individuals on behalf of the Bright Side Factory.  For more
 * information on the Bright Side Factory, please see
 * <http://www.bs-factory.org/>.
 */
package com.bsf.lovDemo.views;

import com.bsf.lovDemo.components.ExitDialog;
import com.bsf.lovDemo.util.help.HelpNode;
import com.jgoodies.swing.application.AbstractMainFrame;
import com.jgoodies.swing.application.Workbench;

import javax.swing.JComponent;
import java.awt.Cursor;
import java.awt.Dimension;

/**
 * The main frame for the Demo application. It creates the menus, menu bar,
 * tool bar and all subpanels. It uses the JGoodies framework (you can check
 * this framework at http://www.jgoodies.com).
 */
public final class DemoFrame extends AbstractMainFrame {
    private static final Dimension MINIMUM_SIZE = new Dimension( 900, 700 );

    private MainPage _mainPage = null;
    private ExitDialog _exitDialog = null;

    // *************************************************************************
    // ***************************** Constructors ******************************
    // *************************************************************************

    /**
     * Constructs an instance of the app's main frame.
     */
    public DemoFrame() {
        super( Workbench.getGlobals().getWindowTitle() );

        _exitDialog = new ExitDialog( this );
    }

    // *************************************************************************
    // *************************** Overiden Methods ****************************
    // *************************************************************************

    /**
     * Opens the main frame and may pop up the tip of the day.
     */
    public void open() {
        super.open();

        // Initial Position
        if ( getWidth() < MINIMUM_SIZE.width ) {
            setBounds( 75, 40, MINIMUM_SIZE.width, MINIMUM_SIZE.height );
        }
    }

    /**
     * The application will not end because we use the system property
     * jgoodies.SystemExitAllowed. We can then add the code to show the
     * ending dialog.
     */
    public void aboutToExitApplication() {
        super.aboutToExitApplication();

        // We display the ending dialog (Thank you for....)
        _exitDialog.open();
    }

    // *************************************************************************
    // **************************** Design Methods *****************************
    // *************************************************************************

    protected JComponent buildContentPane() {
        if ( _mainPage == null ) {
            // We inistantiate the main page
            _mainPage = new MainPage();

            // Building its design
            _mainPage.build();
        }

        // and returning it
        return _mainPage;
    }

    /**
     * @return the frame's minimum size (overiding parent size)
     */
    public Dimension getWindowMinimumSize() {
        return MINIMUM_SIZE;
    }

    // *************************************************************************
    // **************************** Action Methods *****************************
    // *************************************************************************

    /**
     *
     * @param p_displayedInternalFrame one of the constant available like
     * WELCOME_INTERNAL_FRAME or LOV_IN_TABLE_INTERNAL_FRAME... If an
     * invalid value is given, the welcome internal frame is displayed.
     *
     * @see MainPage
     */
    public void setDisplayedInternalFrame( int p_displayedInternalFrame ) {
        _mainPage.setDisplayedInternalFrame( p_displayedInternalFrame );
    }

    /**
     * Displays the url of the given help node, if any, in the HelpContentIF.
     *
     * @param p_helpNode The node whose help page must be displayed. Does
     * nothing if null.
     */
    public void setDisplayedHelpNodeInHelpContent( HelpNode p_helpNode ) {
        _mainPage.setDisplayedHelpNodeInHelpContent( p_helpNode );
    }

    /**
     * Sets the mouse cursor to busy using the glassPane.
     */
    public void setMouseCursorBusy() {
        getGlassPane().setVisible( true );

        getGlassPane().setCursor( Cursor.getPredefinedCursor( Cursor.WAIT_CURSOR ) );
    }

    /**
     * Sets the mouse cursor to idle using the glassPane.
     */
    public void setMouseCursorIdle() {
        getGlassPane().setVisible( false );

        getGlassPane().setCursor( Cursor.getPredefinedCursor( Cursor.DEFAULT_CURSOR ) );
    }
}
