/**
 * Copyright (c) 2002 Bright Side Factory.  All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 *
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 *
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in
 *    the documentation and/or other materials provided with the
 *    distribution.
 *
 * 3. The end-user documentation included with the redistribution,
 *    if any, must include the following acknowledgment:
 *       "This product includes software developed by the
 *        Bright Side Factory (http://www.bs-factory.org/)."
 *    Alternately, this acknowledgment may appear in the software itself,
 *    if and wherever such third-party acknowledgments normally appear.
 *
 * 4. The names "Bright Side", "BS Factory" and "Bright Side Factory" must
 *    not be used to endorse or promote products derived from this
 *    software without prior written permission. For written
 *    permission, please contact info@bs-factory.org.
 *
 * 5. Products derived from this software may not be called "Bright Side",
 *    nor may "Bright Side" appear in their name, without prior written
 *    permission of the Apache Software Foundation.
 *
 * THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
 * OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 * DISCLAIMED.  IN NO EVENT SHALL THE APACHE SOFTWARE FOUNDATION OR
 * ITS CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
 * LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
 * USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
 * ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
 * OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 * SUCH DAMAGE.
 * ====================================================================
 *
 * This software consists of voluntary contributions made by many
 * individuals on behalf of the Bright Side Factory.  For more
 * information on the Bright Side Factory, please see
 * <http://www.bs-factory.org/>.
 */
package com.bsf.lovDemo.views.internalFrames;

import com.bsf.lovDemo.util.help.HelpNode;
import com.bsf.lovDemo.util.help.HelpTreeModel;
import com.bsf.lovDemo.views.DemoFrame;
import com.jgoodies.swing.ExtTree;
import com.jgoodies.swing.application.ResourceManager;
import com.jgoodies.swing.application.Workbench;
import com.jgoodies.swing.panels.SimpleInternalFrame;

import javax.swing.JLabel;
import javax.swing.JPanel;
import javax.swing.JTree;
import javax.swing.event.TreeSelectionEvent;
import javax.swing.event.TreeSelectionListener;
import javax.swing.tree.DefaultTreeCellRenderer;
import javax.swing.tree.TreePath;
import javax.swing.tree.TreeSelectionModel;
import java.awt.BorderLayout;
import java.awt.Component;

/**
 * The help getQuickStartInternalFrame is a view that displays a _topicsTree of help nodes.
 * These trees are set dynamically by the UpdateManager, which
 * in turn uses one of the static help sets defined in class HelpSets.
 */
public final class HelpNavigatorInternalFrame extends SimpleInternalFrame {
    private ExtTree _topicsTree;

    /**
     * Constructs a <code>HelpNavigatorInternalFrame</code>.
     */
    public HelpNavigatorInternalFrame() {
        super( ResourceManager.getString( "help.navigator.title" )
        );

        setSelected( true );
        configureContentPane();
    }

    /**
     * Answers the selected help navigation item.
     */
    public HelpNode getSelectedHelpNode() {
        return (HelpNode) _topicsTree.getLastSelectedPathComponent();
    }

    /**
     * Selects the given node... Does nothing if not present...
     */
    public void setSelectedHelpNode( HelpNode p_helpNode ) {
        if ( p_helpNode == null ) {
            _topicsTree.clearSelection();
        } else {
            _topicsTree.setSelectionPath( new TreePath( p_helpNode.getPath() ) );
        }
    }

    /**
     * Builds the <code>ExtTree</code> utilized for this
     * <code>HelpNavigatorInternalFrame</code>.
     */
    private void configureContentPane() {
        _topicsTree = new ExtTree( new HelpTreeModel() );

        _topicsTree.setOpaque( true );
        _topicsTree.setRootVisible( false );
        _topicsTree.setShowsRootHandles( false );
        _topicsTree.setCellRenderer( new HelpNavigatorCellRenderer() );
        _topicsTree.getSelectionModel().setSelectionMode( TreeSelectionModel.SINGLE_TREE_SELECTION );

        _topicsTree.expandTopLevel();

        _topicsTree.addTreeSelectionListener( new TreeSelectionListener() {
            public void valueChanged( TreeSelectionEvent e ) {
                ( (DemoFrame) Workbench.getMainFrame() ).setDisplayedHelpNodeInHelpContent( getSelectedHelpNode() );
            }
        } );

        JPanel panel = new JPanel( new BorderLayout() );
        panel.add( _topicsTree, BorderLayout.CENTER );

        setContent( panel );
    }

    // A _topicsTree cell renderer that uses special HelpNode properties.
    private static class HelpNavigatorCellRenderer extends DefaultTreeCellRenderer {
        public HelpNavigatorCellRenderer() {
            super();
        }

        public Component getTreeCellRendererComponent( JTree tree, Object value, boolean sel, boolean expanded, boolean leaf, int row, boolean focused ) {
            JLabel label = (JLabel) super.getTreeCellRendererComponent( tree, value, selected, expanded, false, row, focused );

            if ( value != null ) {
                ExtTree extTree = (ExtTree) tree;
                HelpNode item = (HelpNode) value;

                // Why do we have to set the parent selected variable ?
                selected = sel;

                label.setIcon( item.getIcon( sel ) );
                label.setFont( item.isChapter() ? extTree.getBoldFont() : extTree.getFont() );
                label.setForeground( sel ? getTextSelectionColor() : getTextNonSelectionColor() );
                label.setBackground( sel ? getBackgroundSelectionColor() : getBackgroundNonSelectionColor() );
            }

            return label;
        }
    }
}